#Intent:Analyzing Community Data from GLORIA downslope for AJB ms submission
#Author: Meagan F. Oldfather
#Date Created: 20190501
#Date Last Edited: 201905015

#There are three nested scales we can consider: 1) How the community varies across the elevation gradient of the entire mountain range, 2) How the community varies across the elevation gradient of a single peak, 3) How the community varies across the elevation contour with in a transect 

#For this analysis we will focus on community composition (Bray-Curis Dissimilarity)

#Libraries:
library(picante)
library(lubridate)
library(ggplot2)
library(viridisLite)
library(dplyr)
library(vegan)

# Bring in data: 
freq <- read.csv("data/data_raw/downslope_freq_clean.csv", stringsAsFactors = F)
freq <- freq[,-1]
freq$abundance<- freq$seg_01+freq$seg_02+freq$seg_03+freq$seg_04+freq$seg_05+freq$seg_06+freq$seg_07+freq$seg_08+freq$seg_09+freq$seg_10
freq <- freq[!is.na(freq$transect),]
head(freq)

pres <- read.csv("data/data_raw/downslope_pres_clean.csv", stringsAsFactors = F)  
pres <- pres[,-1]
pres$abundance<- pres$seg_01+pres$seg_02+pres$seg_03+pres$seg_04+pres$seg_05+pres$seg_06+pres$seg_07+pres$seg_08+pres$seg_09+pres$seg_10
head(pres)

#remove rows with non-species names
non.species<-c("bare ground", "rock", "scree", "litter", "Unknown vegetative grass", "vascular plant", "Unknown basal rosette", "overstory","soil bryophytes","Carex rhizomatous")
pres<-pres[!pres$species %in% non.species,]
freq<-freq[!freq$species %in% non.species,]

# remove all species names with only "sp" at the end
pres<-pres[!grepl("sp$", pres$species),]
freq<-pres[!grepl("sp$", freq$species),]

# look at all the species in the two datasets (132 in total)
unique(pres$species)
unique(freq$species)

# make date column be a readable date
pres$date <- mdy(pres$date)
pres$year <-year(pres$date)

freq$date <- mdy(freq$date)
freq$year <-year(freq$date)

# look at summit year combinations
unique(pres[,c("summit", "year")])
unique(freq[,c("summit", "year")])

# subset data to only first survey of peak
pres <- subset(pres, year == 2011 | year == 2012 | year == 2013)
freq <- subset(freq, year == 2011 | year == 2012 | year == 2013)

# Scale 1: Looking across the elevation gradient of the entire mountain range
# make a dataframe with peak names and elevations of transects
summit.elevation <- pres[!duplicated(pres$elevation), c("summit", "elevation")]
summit.elevation <- summit.elevation[order(summit.elevation$elevation),]
summit.elevation

# turn in communtity matrices based on BC dissimilarity
pres.mat <- sample2matrix(pres[,c(5,18,7)])
pres.mat

freq.mat <- sample2matrix(freq[,c(5,18,7)])
freq.mat

# Make Figure
NMDS<-metaMDS(freq.mat,distance = "bray",trymax=100)
stressplot(NMDS)
summary(NMDS)

vec.sp<-envfit(NMDS ~ elevation, summit.elevation)
vec.sp
scores(vec.sp)  

summit.elevation.factor <-
summit.elevation %>% 
dplyr::mutate(summit = factor(summit, levels = c("WMT", "BAR", "SME", "PGS", "CPT")))

#pdf(file = "figures/AJB_NMDS_FIGURE.pdf", width = 7.25)
ordiplot(NMDS,type = "n")
priSpp <- diversity(freq.mat, index = "invsimpson", MARGIN = 2)
colors= viridis(5)
ordiellipse(NMDS,group=summit.elevation.factor$summit, lty="dashed", col = colors, lwd = 3, kind ="sd")
orditorp(NMDS,display = "species",priority=priSpp, cex = .8) 
legend("topright",legend = levels(summit.elevation.factor$summit),bty = "n",col = colors, pch=1, pt.bg = colors, cex =.8)
plot(vec.sp, col = "black", cex=1)
#dev.off()

# MANOVA
pres.fit <- adonis(pres.mat ~ summit.elevation$elevation) 
pres.fit #30% of the community variation range-wide is explained by elevation 

freq.fit <- adonis(freq.mat ~ summit.elevation$elevation) 
freq.fit #30% of the community variation range-wide is explained by elevation; interesting that both metrics of abundance are similiar 

# Scale 2: Looking at the elevation gradients within each peak
unique(pres$summit)
unique(freq$summit) 

#BAR
pres.bar.mat <- sample2matrix(pres[pres$summit == "BAR",c(5,18,7)]) 
pres.bar.mat
pres.bar.mat.fit <- adonis(pres.bar.mat ~ as.numeric(rownames(pres.bar.mat)))
pres.bar.mat.fit # 42% of the community variation explained

freq.bar.mat <- sample2matrix(freq[freq$summit == "BAR",c(5,18,7)]) 
freq.bar.mat
freq.bar.mat.fit <- adonis(freq.bar.mat ~ as.numeric(rownames(freq.bar.mat)))
freq.bar.mat.fit # 41% of the community variation explained

#CPT
pres.cpt.mat <- sample2matrix(pres[pres$summit == "CPT",c(5,18,7)]) 
pres.cpt.mat
pres.cpt.mat.fit <- adonis(pres.cpt.mat ~ as.numeric(rownames(pres.cpt.mat)))
pres.cpt.mat.fit # 37% of the community variation explained

freq.cpt.mat <- sample2matrix(freq[freq$summit == "CPT",c(5,18,7)]) 
freq.cpt.mat
freq.cpt.mat.fit <- adonis(freq.cpt.mat ~ as.numeric(rownames(freq.cpt.mat)))
freq.cpt.mat.fit # 34% of the community variation explained

#PGS
pres.pgs.mat <- sample2matrix(pres[pres$summit == "PGS",c(5,18,7)]) 
pres.pgs.mat
pres.pgs.mat.fit <- adonis(pres.pgs.mat ~ as.numeric(rownames(pres.pgs.mat)))
pres.pgs.mat.fit # 40% of the community variation explained

freq.pgs.mat <- sample2matrix(freq[freq$summit == "PGS",c(5,18,7)]) 
freq.pgs.mat
freq.pgs.mat.fit <- adonis(freq.pgs.mat ~ as.numeric(rownames(freq.pgs.mat)))
freq.pgs.mat.fit # 39% of the community variation explained

#SME
pres.sme.mat <- sample2matrix(pres[pres$summit == "SME",c(5,18,7)]) 
pres.sme.mat
pres.sme.mat.fit <- adonis(pres.sme.mat ~ as.numeric(rownames(pres.sme.mat)))
pres.sme.mat.fit # 42% of the community variation explained

freq.sme.mat <- sample2matrix(freq[freq$summit == "SME",c(5,18,7)]) 
freq.sme.mat
freq.sme.mat.fit <- adonis(freq.sme.mat ~ as.numeric(rownames(freq.sme.mat)))
freq.sme.mat.fit # 41% of the community variation explained

#WMT
pres.wmt.mat <- sample2matrix(pres[pres$summit == "WMT",c(5,18,7)]) 
pres.wmt.mat
pres.wmt.mat.fit <- adonis(pres.wmt.mat ~ as.numeric(rownames(pres.wmt.mat)))
pres.wmt.mat.fit # 53% of the community variation explained

freq.wmt.mat <- sample2matrix(freq[freq$summit == "WMT",c(5,18,7)]) 
freq.wmt.mat
freq.wmt.mat.fit <- adonis(freq.wmt.mat ~ as.numeric(rownames(freq.wmt.mat)))
freq.wmt.mat.fit # 52% of the community variation explained


