# Purpose: climate niche means for each segment using TerraClimate climate data

library(tidyverse)
library(raster)
library(sf)
library(cowplot)
library(lubridate)
library(lme4)
library(lmerTest)
library(MuMIn)

pres <- read_csv("data/data_raw/downslope_pres_clean.csv")

meta <- 
  read_csv("data/data_raw/Downslope_metadata.csv") %>% 
  dplyr::rename(transect = `transect#`) %>% 
  group_by(summit, transect) %>% 
  summarize(elevation = mean(elevation, na.rm = TRUE)) %>% 
  dplyr::select(summit, transect, elevation)%>%
  rename(summit=summit)

meta[meta$summit == "WMT" & meta$transect == 5, "elevation"] <- mean(c(4220, 4176))

meta <- rbind(as.data.frame(meta), data.frame(summit = "WMT", transect = 10, elevation = mean(c(4085, 4046)))) %>% as_tibble()

pres <- pres[,-1]

#remove rows with non-species names
non.species<-c("bare ground", "rock", "scree", "litter", "Unknown vegetative grass", "vascular plant", "Unknown basal rosette", "overstory","soil bryophytes","Carex rhizomatous")
pres <- pres[!pres$species %in% non.species,]

# replace spp. with subsp. to match herbarium records
pres$species<-gsub("ssp.","subsp.", pres$species, fixed = T)

# add in periods after all "var" to match herbarium records
pres$species<-gsub("var ","var. ", pres$species, fixed = T)

# remove all species names with only "sp" at the end
pres<-pres[!grepl("sp$", pres$species),]

# Currently there are only 7 non-matches; need to be fixed both here and for the freqency or presence data, whichever is going to be used to calculate the "weight" for the weighted climate niche mean (Mike says there a couple more that need to fixed too as of 20170525)
# 1. Potentilla jepsoni ---> need to add additional i
pres[pres$species == "Potentilla jepsoni", "species"]<- "Potentilla jepsonii"

# 2. Leptosiphon nuttalli  ---> need to add additional i
pres[pres$species == "Leptosiphon nuttalli", "species"]<- "Leptosiphon nuttallii"

# 3. Ipomopsis congesta var. montana needs to be changed to subspecies
pres[pres$species == "Ipomopsis congesta var. montana", "species"]<- "Ipomopsis congesta subsp. montana"

# 4. Woodsia scopulina var. scopulina needs to be changed to subspecies
pres[pres$species == "Woodsia scopulina var. scopulina", "species"]<- "Woodsia scopulina subsp. scopulina"

# 5. Heuchera parviflora needs to be changed to Heuchera parvifolia  
pres[pres$species == "Heuchera parviflora", "species"]<- "Heuchera parvifolia"

# 6. "Calamagrostis pupurascens" needs to be changed to "Calamagrostis purpurascens"
pres[pres$species == "Calamagrostis pupurascens", "species"]<- "Calamagrostis purpurascens"

# 7.Change Oxytropis  viscida to Oxytropis borealis var. viscida
pres[pres$species == "Oxytropis  viscida", "species"]<- "Oxytropis borealis var. viscida"



# Richness per peak -------------------------------------------------------
rich_WMT<-unique(pres[pres$summit=="WMT",]$species)
rich_BAR<-unique(pres[pres$summit=="BAR",]$species)
rich_SME<-unique(pres[pres$summit=="SME",]$species)
rich_CPT<-unique(pres[pres$summit=="CPT",]$species)
rich_PGS<-unique(pres[pres$summit=="PGS",]$species)

rich<-data.frame(summit=c('WMT','BAR','SME','CPT','PGS'), richness=rbind(length(rich_WMT), length(rich_BAR), length(rich_SME), length(rich_CPT),length(rich_PGS)))

write.csv(rich, file="data/data_output/peak richness.csv")

# CNM extraction ----------------------------------------------------------


gloria.herbarium.climate.vals <- read.csv("data/data_output/ggb-climate-niches_terraclimate_1961-1990_one-record-per-cell.csv", stringsAsFactors = FALSE)

cnm <-
  gloria.herbarium.climate.vals %>% 
  group_by(species) %>% 
  summarize(precip_cnm = mean(precip, na.rm = TRUE),
            tmax7_cnm = mean(tmax7, na.rm = TRUE),
            tmin1_cnm = mean(tmin1, na.rm = TRUE),
            cwd_cnm = mean(cwd, na.rm = TRUE))

cnm

# Filter to 2011, 2012, and 2013 ------------------------------------------
pres <-
  pres %>% 
  dplyr::mutate(date = mdy(date)) %>% 
  dplyr::mutate(year = year(date)) %>% 
  dplyr::filter(year %in% 2011:2013)



# CNMs by species ---------------------------------------------------------
cnm_species<-
  pres%>%gather(key=segment, value=present, starts_with("seg")) %>%
  dplyr::filter(present == 1) %>%
  dplyr::group_by(summit, transect, species) %>%
  summarize(abundance = sum(present)) %>% 
  dplyr::left_join(cnm, by = "species")%>%
  dplyr::mutate_if(is.numeric, ~round(.,1))

cnm_species<-cnm_species[!duplicated(cnm_species$species),]
cnm_species<-cnm_species[order(cnm_species$species),]
cnm_species<-
cnm_species<-cnm_species[,-c(1,2,4)]


write.csv(cnm_species, file="data/data_output/cnm_species.csv")

# CCNMs -------------------------------------------------------------------

cw_cnm <-
  pres %>% 
  tidyr::gather(key = segment, value = present, starts_with("seg_")) %>% 
  dplyr::filter(present == 1) %>% 
  dplyr::group_by(summit, transect, species) %>% 
  summarize(abundance = sum(present)) %>% 
  dplyr::left_join(cnm, by = "species") %>% 
  dplyr::summarize(precip_cw_cnm = weighted.mean(x = precip_cnm, w = abundance),
                   tmax7_cw_cnm = weighted.mean(x = tmax7_cnm, w = abundance),
                   tmin1_cw_cnm = weighted.mean(x = tmin1_cnm, w = abundance),
                   cwd_cw_cnm = weighted.mean(x = cwd_cnm, w = abundance)) %>% 
  dplyr::left_join(meta) %>% 
  dplyr::ungroup() %>% 
  dplyr::mutate(summit = factor(summit, levels = c("WMT", "BAR", "SME", "PGS", "CPT")))


cwd_cw_cnm_gg <-
  ggplot(cw_cnm, aes(x = elevation, y = cwd_cw_cnm)) +
  geom_point(aes(color = summit)) +
  geom_smooth(color = "black", method = "lm", formula = y~x) +
  geom_smooth(aes(color = summit, linetype=summit), method = "lm", se = FALSE) +
  scale_linetype_manual(values=c("solid","solid","dashed","solid","dashed"), guide=FALSE)+
  scale_color_viridis_d() +
  theme_bw() +
  labs(x = NULL,
       y = expression(CWD~CNM~(mm)))+
  theme(axis.text=element_text(size=12),
        axis.title=element_text(size=16))


precip_cw_cnm_gg <-
  ggplot(cw_cnm, aes(x = elevation, y = precip_cw_cnm)) +
  geom_point(aes(color = summit)) +
  geom_smooth(color = "black", method = "lm", formula = y~x) +
  geom_smooth(aes(color = summit, linetype=summit), method = "lm", se = FALSE) +
  scale_linetype_manual(values=c("solid","solid","dashed","dashed","dashed"))+
  scale_color_viridis_d() +
  theme_bw() +
  labs(x = NULL,
       y = expression(MAP~CNM~(mm)))+
  theme(axis.text=element_text(size=12),
        axis.title=element_text(size=16))

tmax7_cw_cnm_gg <-
  ggplot(cw_cnm, aes(x = elevation, y = tmax7_cw_cnm)) +
  geom_point(aes(color = summit)) +
  geom_smooth(color = "black", method = "lm", formula = y~x) +
  geom_smooth(aes(color = summit, linetype=summit), method = "lm", se = FALSE) +
  scale_linetype_manual(values=c("dashed","solid","dashed","solid","dashed"))+
  scale_color_viridis_d() +
  theme_bw() +
  labs(x = NULL,
       y = expression(July~T[max]~CNM~"(?C)"))+
  theme(axis.text=element_text(size=12),
        axis.title=element_text(size=16))

tmin1_cw_cnm_gg <-
  ggplot(cw_cnm, aes(x = elevation, y = tmin1_cw_cnm)) +
  geom_point(aes(color = summit)) +
  geom_smooth(color = "black", method = "lm", formula = y~x) +
  geom_smooth(aes(color = summit, linetype=summit), method = "lm", se = FALSE) +
  scale_linetype_manual(values=c("solid","solid","dashed","dashed","dashed"), guide=FALSE)+
  scale_color_viridis_d() +
  theme_bw() +
  labs(color="Summit",
       x = NULL,
       y = expression(Jan~T[min]~CNM~"(?C)"))+
  theme(axis.text=element_text(size=12),
        axis.title=element_text(size=16))

shared_legend <- cowplot::get_legend(tmin1_cw_cnm_gg + theme(legend.direction = "vertical", legend.justification="center" ,legend.box.just = "bottom"))


panel_plot_just_figures <- cowplot::plot_grid(cwd_cw_cnm_gg + theme(legend.position = "none"), 
                                              precip_cw_cnm_gg + theme(legend.position = "none"),
                                              tmax7_cw_cnm_gg + theme(legend.position = "none"),
                                              tmin1_cw_cnm_gg + theme(legend.position = "none"),
                                              ncol = 2, nrow = 2, labels = LETTERS[1:4])

panel_plot_with_legend <- cowplot::plot_grid(panel_plot_just_figures, 
                                             shared_legend,
                                             ncol = 2, rel_widths = c(1, 0.1))

panel_plot_with_xlab <- add_sub(panel_plot_with_legend, "Elevation(m)", size=16)

ggdraw(panel_plot_with_xlab)

ggsave(filename = "figures/cnm-per-transect_terraclimate.pdf", plot = panel_plot_with_xlab, width=7.25, units="in")

# Models -----------------------------------------------------------------
# Range-wide models ======================================================

#CWD
head(cw_cnm)
fit_cwd<-lmer(cwd_cw_cnm~elevation+(1|summit), data=cw_cnm)
summary(fit_cwd)
anova(fit_cwd)
r.squaredGLMM(fit_cwd) # marginal R2 = 80%

fit_cwd2<-lmer(cwd_cw_cnm~elevation+I(elevation^2)+(1|summit), data=cw_cnm)
summary(fit_cwd2)
anova(fit_cwd2)
r.squaredGLMM(fit_cwd2) # marginal R2 = 79%

AICc(fit_cwd, fit_cwd2) #linear model wins

#precip
fit_precip<-lmer(precip_cw_cnm~elevation+(1|summit), data=cw_cnm)
summary(fit_precip)
anova(fit_precip)
r.squaredGLMM(fit_precip) # marginal R2 = 63%

fit_precip2<-lmer(precip_cw_cnm~elevation+I(elevation^2)+(1|summit), data=cw_cnm)
summary(fit_precip2)
anova(fit_precip2)
r.squaredGLMM(fit_precip2) # marginal R2 = 71%

AICc(fit_precip, fit_precip2) #linear model wins

#tmax7
fit_tmax7<-lmer(tmax7_cw_cnm~elevation+(1|summit), data=cw_cnm)
summary(fit_tmax7)
anova(fit_tmax7)
r.squaredGLMM(fit_tmax7) # marginal R2 = 72%

fit_tmax72<-lmer(tmax7_cw_cnm~elevation+I(elevation^2)+(1|summit), data=cw_cnm)
summary(fit_tmax72)
anova(fit_tmax72)
r.squaredGLMM(fit_tmax72) # marginal R2 = 72%

AICc(fit_tmax7, fit_tmax72) #linear model wins

#tmin1
fit_tmin1<-lmer(tmin1_cw_cnm~elevation+(1|summit), data=cw_cnm)
summary(fit_tmin1)
anova(fit_tmin1)
r.squaredGLMM(fit_tmin1) # marginal R2 = 65%

fit_tmin12<-lmer(tmin1_cw_cnm~elevation+I(elevation^2)+(1|summit), data=cw_cnm)
summary(fit_tmin12)
anova(fit_tmin12)
r.squaredGLMM(fit_tmin12) # marginal R2 = 65%

AICc(fit_tmin1, fit_tmin12) #linear model wins


# CWD models ===============================================================

summary(lm(cwd_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="WMT",])) # p<0.001; 71%

summary(lm(cwd_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="BAR",])) # p<0.001; 64%

summary(lm(cwd_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="SME",])) # p=.3; 2%

summary(lm(cwd_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="PGS",])) # p=0.001; 82%

summary(lm(cwd_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="CPT",])) # p=.766; 0%

# precip models ===============================================================

summary(lm(precip_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="WMT",])) # p<0.001; 64%

summary(lm(precip_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="BAR",])) # p=0.01; 35%

summary(lm(precip_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="SME",])) # p=0.23; 6%

summary(lm(precip_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="PGS",])) # p=0.23; 9%

summary(lm(precip_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="CPT",])) # p=.26; 7%

# tmax7 models ===============================================================

summary(lm(tmax7_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="WMT",])) # p=0.047; 25%

summary(lm(tmax7_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="BAR",])) # p<0.001; 64%

summary(lm(tmax7_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="SME",])) # p=.10; 18%

summary(lm(tmax7_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="PGS",])) # p=0.002; 78%

summary(lm(tmax7_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="CPT",])) # p=.82; 0%

# tmin1 models ===============================================================

summary(lm(tmin1_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="WMT",])) # p=0.13; 12%

summary(lm(tmin1_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="BAR",])) # p=0.001; 57%

summary(lm(tmin1_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="SME",])) # p=.16; 11%

summary(lm(tmin1_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="PGS",])) # p=0.04; 45%

summary(lm(tmin1_cw_cnm~elevation, data=cw_cnm[cw_cnm$summit=="CPT",])) # p=.40; 0%
