# Make a figure of the correlation between beta diversity per transect and the climate niche mean spreads per transect 

library(tidyverse)
library(cowplot)

cw_cnm_range_per_transect <- 
  read_csv("data/data_output/cw_cnm_spread_per_transect.csv") %>% 
  dplyr::select(summit, transect, elevation, contains("range")) %>% 
  tidyr::gather(key = "climate_var", value = "range", -(1:3)) %>% 
  tidyr::separate(col = climate_var, into = "climate_var", extra = "drop", sep = "_")

cw_cnm_range_per_transect %>% 
  group_by(climate_var) %>% 
  summarize(mean_range = mean(range),
            lwr_range = min(range),
            upr_range = max(range))

beta_per_transect <- 
  read_csv("data/data_output/beta-diversity-per-transect.csv")

betaDiversity_cwcnmRange <-
  cw_cnm_range_per_transect %>% 
  left_join(beta_per_transect) %>% 
  dplyr::mutate(summit = factor(summit, levels = c("WMT", "BAR", "SME", "PGS", "CPT")))

fitted_models <-
  betaDiversity_cwcnmRange %>% 
  group_by(climate_var) %>% 
  nest() %>% 
  dplyr::mutate(model = map(data, .f = function(x) {
    lm(range ~ beta, data = x)
  })) %>% 
  dplyr::mutate(r2 = map(model, .f = function(x) {
    summary(x)$adj.r.squared
  })) %>% 
  dplyr::mutate(p = map(model, .f = function(x) {
    summary(x)$coefficients["beta", "Pr(>|t|)"]
  })) %>% 
  dplyr::mutate(significant = ifelse(p < 0.05, yes = 1, no = 2)) %>% 
  dplyr::mutate(significant = factor(significant)) %>% 
  dplyr::select(climate_var, p, r2, significant) %>% 
  unnest() 

all_data <-
  fitted_models %>% 
  left_join(betaDiversity_cwcnmRange)


# facetted ----------------------------------------------------------------

ggplot(all_data, aes(x = range, y = beta)) +
  geom_point() +
  geom_smooth(method = "lm", aes(lty = significant), color = "black") +
  facet_wrap(vars(climate_var), scales = "free_x") +
  scale_color_viridis_d() +
  theme_classic() +
  labs(x = "Range of climate niche means",
       y = expression(beta~diversity)) +
  theme(legend.position = "none")


# separate panels ---------------------------------------------------------

# CWD

cwd_subset <- all_data %>% filter(climate_var == "cwd")
lty <- 
  cwd_subset %>% 
  pull(significant) %>% 
  as.character() %>% 
  as.numeric() %>% 
  unique()

cwd_beta_v_range <-
  ggplot(cwd_subset, aes(x = range, y = beta)) +
  geom_point() +
  geom_smooth(method = "lm", lty = lty, color = "black") +
  scale_color_viridis_d() +
  theme_classic() +
  labs(x = expression(Range~of~CWD~CCNM~(mm)),
       y = expression(beta~diversity)) +
  theme(legend.position = "none")



# precip ------------------------------------------------------------------

precip_subset <- all_data %>% filter(climate_var == "precip")
lty <- 
  precip_subset %>% 
  pull(significant) %>% 
  as.character() %>% 
  as.numeric() %>% 
  unique()

precip_beta_v_range <-
  ggplot(precip_subset, aes(x = range, y = beta)) +
  geom_point() +
  geom_smooth(method = "lm", lty = lty, color = "black") +
  scale_color_viridis_d() +
  theme_classic() +
  labs(x = expression(Range~of~MAP~CCNM~(mm)),
       y = expression(beta~diversity)) +
  theme(legend.position = "none")

# tmax7 -------------------------------------------------------------------

tmax7_subset <- all_data %>% filter(climate_var == "tmax7")
lty <- 
  tmax7_subset %>% 
  pull(significant) %>% 
  as.character() %>% 
  as.numeric() %>% 
  unique()

tmax7_beta_v_range <-
  ggplot(tmax7_subset, aes(x = range, y = beta)) +
  geom_point() +
  geom_smooth(method = "lm", lty = lty, color = "black") +
  scale_color_viridis_d() +
  theme_classic() +
  labs(x = expression(Range~of~~July~T[max]~CCNM~(degree*C)),
       y = expression(beta~diversity)) +
  theme(legend.position = "none")

# tmin1 -------------------------------------------------------------------

tmin1_subset <- all_data %>% filter(climate_var == "tmin1")
lty <- 
  tmin1_subset %>% 
  pull(significant) %>% 
  as.character() %>% 
  as.numeric() %>% 
  unique()

tmin1_beta_v_range <-
  ggplot(tmin1_subset, aes(x = range, y = beta)) +
  geom_point() +
  geom_smooth(method = "lm", lty = lty, color = "black") +
  scale_color_viridis_d() +
  theme_classic() +
  labs(x = expression(Range~of~Jan~T[min]~CCNM~(degree*C)),
       y = expression(beta~diversity)) +
  theme(legend.position = "none")


# panel plot --------------------------------------------------------------

panel_plot <- plot_grid(cwd_beta_v_range + theme(text = element_text(size = 14)),
                        precip_beta_v_range + theme(text = element_text(size = 14)),
                        tmax7_beta_v_range + theme(text = element_text(size = 14)),
                        tmin1_beta_v_range + theme(text = element_text(size = 14)),
                        labels = LETTERS[1:4])

panel_plot

ggsave(filename = "figures/beta-diversity-vs-cwcnm-range-per-transect.pdf", plot = panel_plot, width = 7.25, units = "in")

ggsave(filename = "figures/beta-diversity-vs-cwcnm-range-per-transect.png", plot = panel_plot, width = 7.25, units = "in")
