# Purpose: Create datasets of climate variables for the GGB species

# Get herbaria records ----------------------------------------------------

herbarium.df <- read.csv("data/data_raw/California_Species_clean_All_epsg_3310.csv", stringsAsFactors = F)

# create vector of unique herbarium names
herbarium.names<-unique(herbarium.df$scientificName) # length = 13,505

# Get GGB downslope presence data -----------------------------------------------------
# This tells us what species to extract from the herbaria records

pres <- read_csv("data/data_raw/downslope_pres_clean.csv")
pres <- pres[,-1]

#remove rows with non-species names
non.species<-c("bare ground", "rock", "scree", "litter", "Unknown vegetative grass", "vascular plant", "Unknown basal rosette", "overstory","soil bryophytes","Carex rhizomatous")
pres <- pres[!pres$species %in% non.species,]

# replace spp. with subsp. to match herbarium records
pres$species<-gsub("ssp.","subsp.", pres$species, fixed = T)

# add in periods after all "var" to match herbarium records
pres$species<-gsub("var ","var. ", pres$species, fixed = T)

# remove all species names with only "sp" at the end
pres<-pres[!grepl("sp$", pres$species),]

# Look at if matches between Gloria species names and herbarium names
# where are the non-matches?
pres %>% 
  dplyr::filter(!(pres$species %in% herbarium.names)) %>% 
  pull(species) %>% 
  unique()


# Fix non-matches bw GGB data and Baldwin et al 2017 ----------------------

# Currently there are only 7 non-matches; need to be fixed both here and for the freqency or presence data, whichever is going to be used to calculate the "weight" for the weighted climate niche mean (Mike says there a couple more that need to fixed too as of 20170525)
# 1. Potentilla jepsoni ---> need to add additional i
pres[pres$species == "Potentilla jepsoni", "species"]<- "Potentilla jepsonii"

# 2. Leptosiphon nuttalli  ---> need to add additional i
pres[pres$species == "Leptosiphon nuttalli", "species"]<- "Leptosiphon nuttallii"

# 3. Ipomopsis congesta var. montana needs to be changed to subspecies
pres[pres$species == "Ipomopsis congesta var. montana", "species"]<- "Ipomopsis congesta subsp. montana"

# 4. Woodsia scopulina var. scopulina needs to be changed to subspecies
pres[pres$species == "Woodsia scopulina var. scopulina", "species"]<- "Woodsia scopulina subsp. scopulina"

# 5. Heuchera parviflora needs to be changed to Heuchera parvifolia  
pres[pres$species == "Heuchera parviflora", "species"]<- "Heuchera parvifolia"

# 6. "Calamagrostis pupurascens" needs to be changed to "Calamagrostis purpurascens"
pres[pres$species == "Calamagrostis pupurascens", "species"]<- "Calamagrostis purpurascens"

# 7.Change Oxytropis  viscida to Oxytropis borealis var. viscida
pres[pres$species == "Oxytropis  viscida", "species"]<- "Oxytropis borealis var. viscida"

# Look at if matches between Gloria species names and herbarium names
all(pres$species %in% herbarium.names) # all matches? Yes!

# create vector of unique species names
ggb_species <- unique(pres$species)
ggb_species # length = 130


# Subset herbarium data to GGB species ------------------------------------

gloria.herbarium.df <-
  herbarium.df %>%
  dplyr::filter(scientificName %in% ggb_species)

write_csv(gloria.herbarium.df, "data/data_output/GGB_Species_clean_All_epsg_3310.csv")

gloria.herbarium.df <- read.csv("data/data_output/GGB_Species_clean_All_epsg_3310.csv", stringsAsFactors = FALSE)


# make herbaria records for GGB species spatial ---------------------------

gloria.herbarium.sf <-
  gloria.herbarium.df %>%
  st_as_sf(coords = c("x_epsg_3310", "y_epsg_3310"), crs = 3310) %>%
  st_transform(4326) # Need to transform to epsg4326 for Earth Engine

gloria.herbarium.sf_shp <-
  gloria.herbarium.sf %>%
  dplyr::select(id, scientificName, current_name_binomial, current_genus, current_species) %>%
  dplyr::rename(species = scientificName, current_bi = current_name_binomial, current_gn = current_genus, current_sp = current_species)

st_write(gloria.herbarium.sf_shp, "data/data_output/ggb-species-herbaria-records/ggb-species-herbaria-records.shp", delete_dsn = TRUE)

# Upload shapefile to Earth Engine ----------------------------------------
# Use TerraClimate to extract MAP, CWD, July max, Jan min -----------------
# Annual averages for 1961 to 1990
# Downloaded file is a .csv -----------------------------------------------

gloria.herbarium.climate.vals.terraclimate <- read.csv("data/data_output/ggb-climate-niches_terraclimate_1961-1990.csv", stringsAsFactors = FALSE)

# subset so that only one representative record per TerraClimate ce --------
# n column represents the number of samples per species that were found
# in a particular TerraClimate grid cell (2.5 minute resolution; ~4 km)

gloria.herbarium.climate.vals.terraclimate <-
  gloria.herbarium.climate.vals.terraclimate %>% 
  group_by(species, .geo, def, pr, tmmx, tmmn) %>% 
  summarize(n = n()) %>% 
  dplyr::select(species, def, pr, tmmx, tmmn, n, .geo) %>% 
  dplyr::rename(cwd = def, precip = pr, tmax7 = tmmx, tmin1 = tmmn)

write_csv(gloria.herbarium.climate.vals.terraclimate, 
          path = "data/data_output/ggb-climate-niches_terraclimate_1961-1990_one-record-per-cell.csv")

cnm_terraclimate <-
  gloria.herbarium.climate.vals.terraclimate %>% 
  group_by(species) %>% 
  summarize(precip_cnm = mean(precip, na.rm = TRUE),
            tmax7_cnm = mean(tmax7, na.rm = TRUE),
            tmin1_cnm = mean(tmin1, na.rm = TRUE),
            cwd_cnm = mean(cwd, na.rm = TRUE))

cnm_terraclimate


# Use herbaria records to get climate variables from BCM and PRISM --------
# Using climate normals from 1951 to 1980

# CWD first ---------------------------------------------------------------
# Already in EPSG3310

cwd <- raster::raster("data/data_raw/cwd1951_1980_ave_HST.asc")
crs(cwd)<-CRS('+init=EPSG:3310')
cwd[cwd < 0] <- NA
plot(cwd)



# Mean annual precip next -------------------------------------------------
prec <- raster::raster("data/data_raw/PrecAN_HST1951_1980.asc")
crs(prec)<-CRS('+init=EPSG:3310')

bb <- extent(-415888.0930, 552169.1580, -601592.7037, 457509.0195)
extent(prec) <- bb
prec <- setExtent(prec, bb, keepres = TRUE)


# July max temp -----------------------------------------------------------
tmax7 <- raster::raster("data/data_raw/Tmax07_HST1951_1980.asc")
crs(tmax7)<-CRS('+init=EPSG:3310')

bb <- extent(-415888.0930, 552169.1580, -601592.7037, 457509.0195)
extent(tmax7) <- bb
tmax7 <- setExtent(tmax7, bb, keepres = TRUE)


# Jan min temp ------------------------------------------------------------
tmin1 <- raster::raster("data/data_raw/Tmin01_HST1951_1980.asc")
crs(tmin1) <- CRS('+init=EPSG:3310')

bb <- extent(-415888.0930, 552169.1580, -601592.7037, 457509.0195)
extent(tmin1) <- bb
tmin1 <- setExtent(tmin1, bb, keepres = TRUE)


gloria.herbarium.climate.vals_prism <-
  gloria.herbarium.df %>% 
  st_as_sf(coords = c("x_epsg_3310", "y_epsg_3310"), crs = 3310, remove = FALSE) %>% 
  dplyr::mutate(cwd = raster::extract(cwd, .),
                precip = raster::extract(prec, .),
                tmax7 = raster::extract(tmax7, .),
                tmin1 = raster::extract(tmin1, .))


gloria.herbarium.climate.vals_prism_df <-
  gloria.herbarium.climate.vals_prism %>% 
  st_drop_geometry()

write_csv(gloria.herbarium.climate.vals_prism_df, path = "data/data_output/ggb-climate-niches_prism-bcm_1951-1980.csv")


