# Purpose: create a "geographic extent" figure

library(tidyverse)
library(tmap)
library(sf)
library(raster)
library(viridis)
library(spData)
library(grid)

dem <- raster::raster("data/data_output/10m-dem-gloria-downslope.tif")

downslope_coords <- 
  read_csv("data/features/downslope-coordinates.csv") %>% 
  st_as_sf(coords = c("longitude", "latitude"), crs = 4326) %>% 
  tidyr::separate(col = name, into = c("summit", "transect")) %>% 
  dplyr::mutate(transect_num = substr(transect, start = 2, stop = 3)) %>% 
  dplyr::mutate(transect_num = as.numeric(transect_num))

summit_print <-
  downslope_coords %>% 
  st_drop_geometry %>% 
  group_by(summit) %>% 
  summarize(Summit = max(transect_num)) %>% 
  dplyr::mutate(Summit = paste0(summit, " (", Summit, " transects)"))

downslope_coords <-
  downslope_coords %>% 
  left_join(summit_print, by = "summit") %>%
  dplyr::mutate(Summit = factor(Summit, levels = c("WMT (14 transects)",
                                                   "BAR (14 transects)",
                                                   "SME (11 transects)",
                                                   "PGS (8 transects)",
                                                   "CPT (9 transects)")))

bbox <- st_polygon(list(matrix(c(-118.27266912295369,37.48960191271004, 
                                 -118.17516546084431,37.48960191271004, 
                                 -118.17516546084431,37.646891276055605, 
                                 -118.27266912295369,37.646891276055605, 
                                 -118.27266912295369,37.48960191271004), 
                               ncol = 2, 
                               byrow = TRUE)))

bbox_center <-
  bbox %>% 
  st_sfc(crs = 4326) %>% 
  st_transform(3310) %>% 
  st_centroid() %>% 
  st_transform(4326)

slope <- terrain(x = dem, opt = "slope", units = "radians")
aspect <- terrain(x = dem, opt = "aspect", units = "radians")
hill <- hillShade(slope, aspect, 40, 270)

# Quick test
plot(hill)
plot(bbox, add = TRUE)
plot(downslope_coords$geometry, add = TRUE)

# Build the main plot
study_extent <-
  tm_shape(hill) +
  tm_raster(palette = gray(0:100 / 100), n = 100, legend.show = FALSE)  +
  tm_shape(dem) +
  tm_raster(alpha = 0.5, palette = terrain.colors(25),
            legend.show = FALSE) +
  tm_shape(downslope_coords) +
  tm_symbols(col = "Summit", size = 0.4, palette = viridis(5)) +
  tm_layout(legend.position = c(0.02, 0.015), legend.frame = TRUE, legend.bg.color = "white", legend.width = -0.45) +
  tm_scale_bar(position = c(0.02, 0.19), breaks = c(0, 1, 2, 3), size = 0.9) +
  tm_grid(n.x = 4, n.y = 7, labels.inside.frame = FALSE, labels.size = 0.4) +
  tm_ylab(text = "Latitude", space = 1.2) +
  tm_xlab(text = "Longitude", space = 1.0)

# Print the plot to the graphics device by using the name
# of the object (just like ggplot2)
# study_extent

western_states <- 
  us_states %>% 
  dplyr::filter(NAME %in% c("California", "Nevada", "Oregon", "Idaho")) %>% 
  st_transform(3310)

broader_extent_bbox <- (st_bbox(western_states) + c(0, 0, -450000, -750000)) %>% st_as_sfc() %>% st_transform(4326) %>% st_bbox()

broader_extent <-
  tm_shape(western_states, projection = 4326, bbox = broader_extent_bbox) + 
  tm_borders() +
  tm_shape(bbox_center) +
  tm_symbols(col = "red", size = 1, shape = 18) +
  tm_compass(type = "arrow", position = c(-0.05, 0.015))

vp <- viewport(x = grid::unit(1.25, "npc"), 
               y = grid::unit(0.985, "npc"), 
               height = 0.35, 
               just = c(1, 1))

study_extent
print(broader_extent, vp = vp)

tmap_save(tm = study_extent, filename = "figures/study-geographic-extent-inset.pdf", insets_tm = broader_extent, insets_vp = vp, width = 3.5, units = "in")

tmap_save(tm = study_extent, filename = "figures/study-geographic-extent-inset.png", insets_tm = broader_extent, insets_vp = vp, width = 3.5, units = "in", dpi = 300)
